# Decorative Images

The **Decorative Images** module aims to enhance accessibility by allowing content editors to designate whether an image is purely decorative or conveys meaningful content. When an image is marked as decorative, it is assigned `role="presentation"` to allow theming for ARIA rules. Site builders may additionally use the Decorative _OR_ alternative text required option.


## Features
- Adds a `Decorative` option to image fields.
- Adds option that requires `Decorative` OR `Alternative text` on the field.
- Adds `role="presentation"` to marked images for theming.
- If role is `presentation`, removes the role and empties the `alt` text.
- Is configured on the frontend under `Edit field`.
- Stores image status using Drupal’s key-value storage.

## Installation & Usage

### Installation
```sh
composer require drupal/decorative_image
drush en -y decorative_image
```

### Configuration

1.  Navigate to **Manage Form Display** for an image field.

2.  Enable the **"Decorative image"** option in the field widget settings.


### Usage

*   When adding or editing an image, check **\[X\] Decorative image** to apply the decorative role.


Technical Notes
---------------

*   To customize how images are processed, refer to these additional functions:
  * template_preprocess_image()
  * template_preprocess_image_formatter()
  * template_preprocess_responsive_image_formatter()


Accessibility Benefits
----------------------

Marking non-informative images as decorative prevents screen readers from announcing them, reducing audible clutter. For best practices, refer to the [W3C decorative images guide](https://www.w3.org/WAI/tutorials/images/decorative/).
