<?php

namespace Drupal\decorative_images\Hooks;

use Drupal\image\Plugin\Field\FieldWidget\ImageWidget;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class to handle widget-related hooks.
 */
class DecorativeWidgetFormAlter {

  /**
   * Alters the image field widget to add the 'Decorative' checkbox.
   */
  public static function alterForm(array &$element, FormStateInterface $form_state, array $context): void {
    $widget = $context['widget'] ?? NULL;

    if (!$widget instanceof ImageWidget || empty($context['items']) || empty($context['items']->getName())) {
      return;
    }

    // Get the field config.
    $entity = $form_state->getFormObject()?->getEntity();
    $field_definition = $entity->getFieldDefinition($context['items']->getName());
    $field_config = \Drupal::entityTypeManager()->getStorage('field_config')->load($field_definition->id());

    if (!$field_config || !$field_config->getThirdPartySetting('decorative_images', 'decorative_enabled')) {
      return;
    }

    // Add the form element.
    $element['is_decorative'] = [
      '#type' => 'checkbox',
      '#title' => t('Decorative image'),
      // Should be pulled from entity metadata if needed.
      '#default_value' => 0,
    ];

    $element['#element_validate'][] = [self::class, 'validateForm'];
  }

  /**
   * Custom validation function for the image widget.
   */
  public static function validateForm($element, FormStateInterface $form_state) {
    $values = $form_state->getValue($element['#parents'] ?? []);
    $field_name = $element['#field_name'] ?? '';
    $entity = $form_state->getFormObject()?->getEntity();
    $field_definition = $entity->getFieldDefinition($field_name);
    $field_config = \Drupal::entityTypeManager()->getStorage('field_config')->load($field_definition->id());

    if (!$field_config) {
      return;
    }

    $decorative_or_alternative_required = $field_config->getThirdPartySetting('decorative_images', 'decorative_or_alternative_required', 0);

    if ($decorative_or_alternative_required && empty($values['alt']) && empty($values['is_decorative'])) {
      $form_state->setError($element['alt'], t('Either alternative text or decorative must be set.'));
    }
  }

}
